@@ -35,7 +35,7 @@ under the same terms as Perl itself.
 
 =cut
 
-our $VERSION = '0.028'; # VERSION
+our $VERSION = '0.029'; # VERSION
 
 use Mouse::Role;
 use Text::CSV::Encoded;
@@ -262,7 +262,9 @@ my %row_makers = (
           warn "not storing duplicate cvterm_dbxref for ", $dbxref_details->{termid};
           ()
         } else {
-          $seen_cvterm_dbxrefs{$key} = $is_for_definition;
+          if ($is_for_definition) {
+            $seen_cvterm_dbxrefs{$key} = 1;
+          }
           [$cvterm_id, $dbxref_id, $is_for_definition]
         }
       };
